<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package WordPress
 * @subpackage The_Secret_World
 * @since The Secret World 1.0
 */
?><!DOCTYPE html>
<!--[if IE 6]>
<html id="ie6" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 7]>
<html id="ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html id="ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 6) | !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<meta name="viewport" content="width=device-width" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'thesecretworld' ), max( $paged, $page ) );

	?></title>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="shortcut icon" href="<?php bloginfo('stylesheet_directory'); ?>/favicon.ico" />
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<link rel="stylesheet" type="text/css" href="<?php bloginfo('template_url'); ?>/css/jquery.jscrollpane.css">
<link rel="stylesheet" type="text/css" href="<?php bloginfo('template_url'); ?>/css/colorbox.css">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
<!--[if lt IE 9]>
<script src="<?php echo get_template_directory_uri(); ?>/js/html5.js" type="text/javascript"></script>
<![endif]-->
<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js"></script>
<script type="text/javascript" src="<?php bloginfo('template_url'); ?>/js/script.js"></script>
<script type="text/javascript" src="<?php bloginfo('template_url'); ?>/js/jquery.jscrollpane.min.js"></script>
<script type="text/javascript" src="<?php bloginfo('template_url'); ?>/js/jquery.colorbox-min.js"></script>
<?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="hfeed">
	<header id="branding" role="banner">
			<hgroup>
				<h1 id="site-title"><span><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></span></h1>
				<h2 id="site-description"><?php bloginfo( 'description' ); ?></h2>
			</hgroup>

			<?php
				// Check to see if the header image has been removed
				$header_image = get_header_image();
				if ( ! empty( $header_image ) ) :
			?>
			<a class="header-logo" href="<?php echo esc_url( home_url( '/' ) ); ?>">
					<img src="<?php header_image(); ?>" width="<?php echo HEADER_IMAGE_WIDTH; ?>" height="<?php echo HEADER_IMAGE_HEIGHT; ?>" alt="" style="position:absolute;top:50%;left:50%;margin-top:-<?php echo (HEADER_IMAGE_HEIGHT/2)+5; ?>px;margin-left:-<?php echo HEADER_IMAGE_WIDTH/2; ?>px;"/>
			</a>
			<?php endif; // end check for removed header image ?>

			<?php if(!is_user_logged_in()): //Check to see if a user is logged in?>
				<div id="login-container" class="not-logged">
					<?php 
					echo get_avatar( '', '40' );
					?>
					<h3>Sign up</h3>
					<?php
						$args_login = array(
							'label_log_in' => 'Go',
							'value_username' => 'Username'
						);
						wp_login_form( $args_login );
					?>
					<div class="links">
						<?php wp_register('', ''); ?>
						<span class="spacer">&nbsp;|&nbsp;</span>
						<a href="" class="forgot">Forgot password?</a>
					</div>
				</div>
			<?php else : ?>
				<div id="login-container" class="logged">
					<?php 
					global $current_user;
					echo get_avatar( $current_user->user_email, '40' );
					?>
					<span class="user-info">Welcome,&nbsp;<a href="/wp-admin/profile.php" class="profile-link"><?php echo $current_user->display_name; ?></a>.&nbsp;<a href="<?php echo wp_logout_url( home_url() ); ?> " class="logout-link">Logout</a></span>
				</div>

			<?php endif; // end check for a logged in user?>

			<nav id="access" role="navigation">
				<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
				<?php get_search_form(); ?>
			</nav><!-- #access -->
	</header><!-- #branding -->


	<div id="main">

	<?php get_sidebar( 'teaser' ); ?>
