<?php
/**
 * Recent_Posts widget class
 *
 * @since 2.8.0
 */
class HE_Widget_Recent_Posts extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_recent_entries', 'description' => __( "The most recent posts on your site") );
		parent::__construct('recent-posts', __('Recent Posts'), $widget_ops);
		$this->alt_option_name = 'widget_recent_entries';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_recent_posts', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title'], $instance, $this->id_base);
		if ( ! $number = absint( $instance['number'] ) )
 			$number = 10;

		$r = new WP_Query(array('posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>

		<?php 
			$count = wp_count_posts();
			$publish = $count->publish;
		?>

		<?php if ( $title ) echo $before_title . $title . '<span class="count">' . $publish . ' posts</span>' . $after_title; ?>

		<div class="recent-posts-container">
		<div class="scroll-pane">
		<ul>
		<?php  while ($r->have_posts()) : $r->the_post(); ?>
		<li><a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>">”

		<?php if ( get_the_excerpt() ){
			$excerpt = get_the_excerpt();
			if (strlen($excerpt) > 50) $excerpt = substr($excerpt,0,strpos($excerpt,' ',50));
			echo $excerpt.'...';
		} else {
		 	the_ID(); 
		} ?>
		“<br/><span class="author"><?php if(get_the_author()) the_author(); else the_ID(); ?></span> <span class="time"><?php the_time('F j, Y g:i'); ?></span></a></li>
		<?php endwhile; ?>
		</ul>
		</div>
		</div>
		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_recent_entries']) )
			delete_option('widget_recent_entries');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_recent_posts', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 10;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

/**
 * Links widget class
 *
 * @since 2.8.0
 */
class HE_Widget_Links extends WP_Widget {

	function __construct() {
		$widget_ops = array('description' => __( "Your blogroll" ) );
		parent::__construct('links', __('Links'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract($args, EXTR_SKIP);

		$show_description = isset($instance['description']) ? $instance['description'] : false;
		$show_name = isset($instance['name']) ? $instance['name'] : false;
		$show_rating = isset($instance['rating']) ? $instance['rating'] : false;
		$show_images = isset($instance['images']) ? $instance['images'] : true;
		$category = isset($instance['category']) ? $instance['category'] : false;

		if ( is_admin() && !$category ) {
			// Display All Links widget as such in the widgets screen
			echo $before_widget . $before_title. __('All Links') . $after_title . $after_widget;
			return;
		}

		$before_widget = preg_replace('/id="[^"]*"/','id="%id"', $before_widget);
		wp_list_bookmarks(apply_filters('widget_links_args', array(
			'title_before' => $before_title, 'title_after' => $after_title,
			'category_before' => $before_widget, 'category_after' => $after_widget,
			'show_images' => $show_images, 'show_description' => $show_description,
			'show_name' => $show_name, 'show_rating' => $show_rating,
			'category' => $category, 'class' => 'linkcat widget',
			'between' => '</span><span class="item">', 'after' => '</li>'
		)));
	}

	function update( $new_instance, $old_instance ) {
		$new_instance = (array) $new_instance;
		$instance = array( 'images' => 0, 'name' => 0, 'description' => 0, 'rating' => 0);
		foreach ( $instance as $field => $val ) {
			if ( isset($new_instance[$field]) )
				$instance[$field] = 1;
		}
		$instance['category'] = intval($new_instance['category']);

		return $instance;
	}

	function form( $instance ) {

		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'images' => true, 'name' => true, 'description' => false, 'rating' => false, 'category' => false ) );
		$link_cats = get_terms( 'link_category');
?>
		<p>
		<label for="<?php echo $this->get_field_id('category'); ?>" class="screen-reader-text"><?php _e('Select Link Category'); ?></label>
		<select class="widefat" id="<?php echo $this->get_field_id('category'); ?>" name="<?php echo $this->get_field_name('category'); ?>">
		<option value=""><?php _e('All Links'); ?></option>
		<?php
		foreach ( $link_cats as $link_cat ) {
			echo '<option value="' . intval($link_cat->term_id) . '"'
				. ( $link_cat->term_id == $instance['category'] ? ' selected="selected"' : '' )
				. '>' . $link_cat->name . "</option>\n";
		}
		?>
		</select></p>
		<p>
		<input class="checkbox" type="checkbox" <?php checked($instance['images'], true) ?> id="<?php echo $this->get_field_id('images'); ?>" name="<?php echo $this->get_field_name('images'); ?>" />
		<label for="<?php echo $this->get_field_id('images'); ?>"><?php _e('Show Link Image'); ?></label><br />
		<input class="checkbox" type="checkbox" <?php checked($instance['name'], true) ?> id="<?php echo $this->get_field_id('name'); ?>" name="<?php echo $this->get_field_name('name'); ?>" />
		<label for="<?php echo $this->get_field_id('name'); ?>"><?php _e('Show Link Name'); ?></label><br />
		<input class="checkbox" type="checkbox" <?php checked($instance['description'], true) ?> id="<?php echo $this->get_field_id('description'); ?>" name="<?php echo $this->get_field_name('description'); ?>" />
		<label for="<?php echo $this->get_field_id('description'); ?>"><?php _e('Show Link Description'); ?></label><br />
		<input class="checkbox" type="checkbox" <?php checked($instance['rating'], true) ?> id="<?php echo $this->get_field_id('rating'); ?>" name="<?php echo $this->get_field_name('rating'); ?>" />
		<label for="<?php echo $this->get_field_id('rating'); ?>"><?php _e('Show Link Rating'); ?></label>
		</p>
<?php
	}
}

class HE_Widget_Social_Networks extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_social_networks', 'description' => __( "Displays your social netwoks") );
		parent::__construct('social-networks', __('Social Networks'), $widget_ops);
		$this->alt_option_name = 'widget_social_networks';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_social_networks', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Join us now on') : $instance['title'], $instance, $this->id_base);

?>
		<?php echo $before_widget; ?>

		<div class="social-networks-container">
		<?php echo $before_title; ?>
		<?php echo $title; ?>
		<?php echo $after_title; ?>
		<ul>
			<?php if($instance['youtube'] != ''){ ?>
			<li>
			<a href="<?php echo $instance['youtube']; ?>" title="YouTube"><img src="<?php bloginfo('template_url'); ?>/images/icon_youtube.png" alt="YouTube"></a>
			</li>
			<?php } ?>
			<?php if($instance['twitter'] != ''){ ?>
			<li>
			<a href="<?php echo $instance['twitter']; ?>" title="Twitter"><img src="<?php bloginfo('template_url'); ?>/images/icon_twitter.png" alt="Twitter"></a>
			</li>
			<?php } ?>
			<?php if($instance['facebook'] != ''){ ?>
			<li>
			<a href="<?php echo $instance['facebook']; ?>" title="Facebook"><img src="<?php bloginfo('template_url'); ?>/images/icon_facebook.png" target="_blank" alt="Facebook"></a>
			</li>
			<?php } ?>
		</ul>
		</div>
		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();



		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_social_networks', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		//$instance['title'] = strip_tags($new_instance['title']);
		$instance['facebook'] = $new_instance['facebook'] != '' ? $this->addProtocol($new_instance['facebook']) : '';
		$instance['twitter'] = $new_instance['twitter'] != '' ? $this->addProtocol($new_instance['twitter']) : '';
		$instance['youtube'] = $new_instance['youtube'] != '' ? $this->addProtocol($new_instance['youtube']) : '';
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_social_networks']) )
			delete_option('widget_social_networks');

		return $instance;
	}

	function addProtocol($str){
		if(!preg_match('/(https?):\/\/*/', $str)) $str = 'http://'.$str;
		return $str;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_social_networks', 'widget');
	}

	function form( $instance ) {
		//$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$facebook = isset($instance['facebook']) ? esc_attr($instance['facebook']) : '';
		$twitter = isset($instance['twitter']) ? esc_attr($instance['twitter']) : '';
		$youtube = isset($instance['youtube']) ? esc_attr($instance['youtube']) : '';
?>
		<!--<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>-->

		<p><label for="<?php echo $this->get_field_id('facebook'); ?>"><?php _e('Facebook profile url:'); ?></label>
		<input id="<?php echo $this->get_field_id('facebook'); ?>" name="<?php echo $this->get_field_name('facebook'); ?>" type="text" value="<?php echo $facebook; ?>" size="" /></p>

		<p><label for="<?php echo $this->get_field_id('twitter'); ?>"><?php _e('Twitter profile url:'); ?></label>
		<input id="<?php echo $this->get_field_id('twitter'); ?>" name="<?php echo $this->get_field_name('twitter'); ?>" type="text" value="<?php echo $twitter; ?>" size="" /></p>

		<p><label for="<?php echo $this->get_field_id('youtube'); ?>"><?php _e('Youtube chanel url:'); ?></label>
		<input id="<?php echo $this->get_field_id('youtube'); ?>" name="<?php echo $this->get_field_name('youtube'); ?>" type="text" value="<?php echo $youtube; ?>" size="" /></p>
<?php
	}
}

class HE_Widget_Members_online extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_members_online', 'description' => __( "Members online") );
		parent::__construct('members-online', __('Members online'), $widget_ops);
		$this->alt_option_name = 'widget_members_online';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('widget_members_online', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Join us now on') : $instance['title'], $instance, $this->id_base);

?>
		<?php echo $before_widget; ?>

		<div class="social-networks-container">
		<?php echo $before_title; ?>
		<?php echo $title; ?>
		<?php echo $after_title; ?>
		<ul>
			<?php if($instance['youtube'] != ''){ ?>
			<li>
			<a href="<?php echo $instance['youtube']; ?>" title="YouTube"><img src="<?php bloginfo('template_url'); ?>/images/icon_youtube.png" alt="YouTube"></a>
			</li>
			<?php } ?>
			<?php if($instance['twitter'] != ''){ ?>
			<li>
			<a href="<?php echo $instance['twitter']; ?>" title="Twitter"><img src="<?php bloginfo('template_url'); ?>/images/icon_twitter.png" alt="Twitter"></a>
			</li>
			<?php } ?>
			<?php if($instance['facebook'] != ''){ ?>
			<li>
			<a href="<?php echo $instance['facebook']; ?>" title="Facebook"><img src="<?php bloginfo('template_url'); ?>/images/icon_facebook.png" alt="Facebook"></a>
			</li>
			<?php } ?>
		</ul>
		</div>
		<?php echo $after_widget; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();



		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('widget_members_online', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['widget_members_online']) )
			delete_option('widget_members_online');

		return $instance;
	}

	function addProtocol($str){
		if(!preg_match('/(https?):\/\/*/', $str)) $str = 'http://'.$str;
		return $str;
	}

	function flush_widget_cache() {
		wp_cache_delete('widget_members_online', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
<?php
	}
}


/**
 * Homepage Widget to display 5 images 
	*add_image_size( 'home-image', '608', '306', true );
	*add_image_size( 'home-thumb', '67', '71', true );
 */
class HE_Widget_HomeImages extends WP_Widget {
  function HE_Widget_HomeImages() {
    $widget_ops = array('classname' => 'he_home_images', 'description' => 'Displays five images');
    $this->WP_Widget('HEHomeImages', 'Recent Medias', $widget_ops);
  }

  function widget($args, $instance) {
	global $_hue_conf;

	$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Medias') : $instance['title'], $instance, $this->id_base);

    extract($args);
    echo $before_widget;
    echo $before_title.$title.$after_title;
    ?>
    <div class="widget-home-img-container">
      <a class="top" onclick="slideUp(this);"></a>
      <a class="bottom" onclick="slideDown(this);"></a>
      <ul>
    <?php
    	//var_dump($instance);

    	$sizes = array();

    	if($instance['use_defaults']){
		$index = 1;
		$limit = $instance['limit'];
		$r = new WP_Query(array('posts_per_page' => $limit, 'no_found_rows' => true, 'post_status' => 'null', 'post_mime_type' => 'image', 'post_type' => 'attachment'));
		if ($r->have_posts()) : ?>
		<?php  while ($r->have_posts()) : $r->the_post(); ?>

			<?php 

				$a = array();
				$a['normal'] = wp_get_attachment_image_src($r->ID, 'full');
				$a['thumb'] = wp_get_attachment_image_src($r->ID, 'home-thumb');
				$a['sidebar'] = wp_get_attachment_image_src($r->ID, 'recent-medias');
				$a['large'] = wp_get_attachment_image_src($r->ID, 'home-image');
				
				$sizes['img'.$index]['normal'] = $a['normal'][0];
		    	$sizes['img'.$index]['thumb'] = $a['thumb'][0];
		    	$sizes['img'.$index]['sidebar'] = $a['sidebar'][0];
		    	$sizes['img'.$index]['large'] = $a['large'][0];

	    			echo '<li>';
	    			echo '<img src="'.$sizes['img'.$index]['thumb'].'" alt="" />';
	    			echo '<a class="cboxElement sidebar-size group2" href="'.$sizes['img'.$index]['normal'].'">';
	    			echo '<img src="'.$sizes['img'.$index]['sidebar'].'" alt="" />';
	    			echo '</a>';
	    			echo '<a class="thumb'.('img'.$index == 'img1' ? ' selected' : '').'" style="cursor:pointer;" onclick="switchMedia(this, \''.'img'.$index.'\');"></a>';
	    			echo '</li>';
	    			
	    		$index++;
			?>

		<?php endwhile; ?>
		<?php endif; ?>

		<?php
    	} else {
	    	foreach($instance as $key=>$value){
	    		//echo $key.' : '.$value.'<br/>';
	    		if($value != null && preg_match('/^img/', $key)){
		    		$sizes[$key]['normal'] = $value;
		    		$sizes[$key]['thumb'] = preg_replace('/(.jpg|.jpeg|.gif|.png)/i', '-67x71$1', $value);
		    		$sizes[$key]['sidebar'] = preg_replace('/(.jpg|.jpeg|.gif|.png)/i', '-212x120$1', $value);
		    		$sizes[$key]['large'] = preg_replace('/(.jpg|.jpeg|.gif|.png)/i', '-604x355$1', $value);

	    			echo '<li>';
	    			echo '<img src="'.$sizes[$key]['thumb'].'" alt="" />';
	    			echo '<a class="cboxElement sidebar-size group2" href="'.$sizes[$key]['normal'].'">';
	    			echo '<img src="'.$sizes[$key]['sidebar'].'" alt="" />';
	    			echo '</a>';
	    			echo '<a class="thumb'.($key == 'img1' ? ' selected' : '').'" style="cursor:pointer;" onclick="switchMedia(this, \''.$key.'\');"></a>';
	    			echo '</li>';
	    		}
	    	}
    	}
    ?>
      </ul>

      <?php foreach($sizes as $key=>$value){ ?>
      <a class="cboxElement <?php echo $key; ?> group1" href="<?php echo $sizes[$key]['normal']; ?>" <?php echo $key == 'img1' ? 'style="z-index:999;"' : ''; ?>>
      	<img class="large" src="<?php echo $sizes[$key]['large']; ?>" alt="" />
      </a>
      <?php } ?>
      </div>
    <?php
    echo $after_widget;
  }

  function update($new_instance, $old_instance) {
    $instance = $old_instance;
    $instance['img1'] = $new_instance['img1'];
    $instance['img2'] = $new_instance['img2'];
    $instance['img3'] = $new_instance['img3'];
    $instance['img4'] = $new_instance['img4'];
    $instance['img5'] = $new_instance['img5'];
    $instance['title'] = $new_instance['title'];
    $instance['use_defaults'] = $new_instance['use_defaults'];
    $instance['limit'] = $new_instance['limit'];
    return $instance;
  }

  function form($instance) {
    //Defaults

    $instance = wp_parse_args( (array) $instance, array( 'img1' => false, 'img2' => false, 'img3' => false, 'img4' => false, 'img5' => false, 'title' => false, 'use_defaults' => true, 'limit' => 10 ) );
      //var_dump($instance);
    ?>
    	<p>
    	<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title'];?>"/>
      	</p>

		<p>
        <input id="<?php echo $this->get_field_id('use_defaults'); ?>" name="<?php echo $this->get_field_name('use_defaults'); ?>" type="checkbox" <?php if($instance['use_defaults']) echo 'checked="checked" ';?>onchange="" />
        <label for="<?php echo $this->get_field_id('use_defaults'); ?>">Use default Medias</label>
      	</p>

		<p>
		<label for="<?php echo $this->get_field_id('limit'); ?>">Limit:</label>
        <select id="<?php echo $this->get_field_id('limit'); ?>" name="<?php echo $this->get_field_name('limit'); ?>">
        	<option value="5"<?php echo $instance['limit'] == '5' ? ' selected="selected"' : '';?>>5</option>
        	<option value="10"<?php echo $instance['limit'] == '10' ? ' selected="selected"' : '';?>>10</option>
        	<option value="15"<?php echo $instance['limit'] == '15' ? ' selected="selected"' : '';?>>15</option>
        	<option value="20"<?php echo $instance['limit'] == '20' ? ' selected="selected"' : '';?>>20</option>
        </select>
      	</p>

      	<div class="extra-fields">

      	<p style="border-top:2px dotted #ccc;border-bottom:2px dotted #ccc;padding:6px 0;">If you don’t use default medias from your Wordpress media library, you can manually enter 5 file url from the library.</p>

    	<p>
        <input id="<?php echo $this->get_field_id('img1'); ?>" name="<?php echo $this->get_field_name('img1'); ?>" type="text" value="<?php echo $instance['img1'];?>"/>
        <label for="<?php echo $this->get_field_id('img1'); ?>">First image</label>
      </p>
    	<p>
        <input id="<?php echo $this->get_field_id('img2'); ?>" name="<?php echo $this->get_field_name('img2'); ?>" type="text" value="<?php echo $instance['img2'];?>"/>
        <label for="<?php echo $this->get_field_id('img2'); ?>">Second image</label>
      </p>
    	<p>
        <input id="<?php echo $this->get_field_id('img3'); ?>" name="<?php echo $this->get_field_name('img3'); ?>" type="text" value="<?php echo $instance['img3'];?>"/>
        <label for="<?php echo $this->get_field_id('img3'); ?>">Third image</label>
      </p>
    	<p>
        <input id="<?php echo $this->get_field_id('img4'); ?>" name="<?php echo $this->get_field_name('img4'); ?>" type="text" value="<?php echo $instance['img4'];?>"/>
        <label for="<?php echo $this->get_field_id('img4'); ?>">Fourth image</label>
      </p>
    	<p>
        <input id="<?php echo $this->get_field_id('img5'); ?>" name="<?php echo $this->get_field_name('img5'); ?>" type="text" value="<?php echo $instance['img5'];?>"/>
        <label for="<?php echo $this->get_field_id('img5'); ?>">Fifth image</label>
      </p>
      </div>
		<?php
    } // function form
} // widget class